@@ -10,6 +10,8 @@
 #' @param verbose Toggle warnings.
 #' @param ... Not used.
 #'
+#' @inheritSection center Selection of variables - the `select` argument
+#'
 #' @return
 #' `x`, where `NA` values are replaced by `replacement`.
 #'
@@ -73,6 +75,15 @@ convert_na_to <- function(x, ...) {
 }
 
 
+#' @export
+convert_na_to.default <- function(x, verbose = TRUE, ...) {
+  if (isTRUE(verbose)) {
+    message(insight::format_message(sprintf("Converting missing values (`NA`) into regular values currently not possible for variables of class '%s'.", class(x)[1])))
+  }
+  x
+}
+
+
 #' @rdname convert_na_to
 #' @export
 convert_na_to.numeric <- function(x, replacement = NULL, verbose = TRUE, ...) {
@@ -131,7 +142,15 @@ convert_na_to.character <- function(x, replacement = NULL, verbose = TRUE, ...)
 #'
 #' @rdname convert_na_to
 #' @export
-convert_na_to.data.frame <- function(x, replace_num = NULL, replace_char = NULL, replace_fac = NULL, select = NULL, exclude = NULL, ignore_case = FALSE, verbose = TRUE, ...) {
+convert_na_to.data.frame <- function(x,
+                                     select = NULL,
+                                     exclude = NULL,
+                                     replace_num = NULL,
+                                     replace_char = NULL,
+                                     replace_fac = NULL,
+                                     ignore_case = FALSE,
+                                     verbose = TRUE,
+                                     ...) {
   data <- x
   select_nse <- .select_nse(select, data, exclude = exclude, ignore_case)
 
