@@ -14,6 +14,8 @@
 #'   the input vector (`range(x)`).
 #' @param ... Arguments passed to or from other methods.
 #'
+#' @inheritSection center Selection of variables - the `select` argument
+#'
 #' @examples
 #' data_rescale(c(0, 1, 5, -5, -2))
 #' data_rescale(c(0, 1, 5, -5, -2), to = c(-5, 5))
@@ -56,6 +58,16 @@ change_scale <- function(x, ...) {
 
 
 
+#' @export
+data_rescale.default <- function(x, verbose = TRUE, ...) {
+  if (isTRUE(verbose)) {
+    message(insight::format_message(paste0("Variables of class '", class(x)[1], "' can't be rescaled and remain unchanged.")))
+  }
+  x
+}
+
+
+
 #' @rdname data_rescale
 #' @export
 data_rescale.numeric <- function(x,
@@ -94,20 +106,12 @@ data_rescale.numeric <- function(x,
 }
 
 
-
-#' @export
-data_rescale.factor <- function(x, ...) {
-  x
-}
-
-
-
 #' @export
 data_rescale.grouped_df <- function(x,
-                                    to = c(0, 100),
-                                    range = NULL,
                                     select = NULL,
                                     exclude = NULL,
+                                    to = c(0, 100),
+                                    range = NULL,
                                     ignore_case = FALSE,
                                     ...) {
   info <- attributes(x)
@@ -129,7 +133,7 @@ data_rescale.grouped_df <- function(x,
   x <- as.data.frame(x)
   for (rows in grps) {
     x[rows, ] <- data_rescale(
-      x[rows, ],
+      x[rows, , drop = FALSE],
       select = select,
       exclude = exclude,
       to = to,
@@ -147,10 +151,10 @@ data_rescale.grouped_df <- function(x,
 #' @rdname data_rescale
 #' @export
 data_rescale.data.frame <- function(x,
-                                    to = c(0, 100),
-                                    range = NULL,
                                     select = NULL,
                                     exclude = NULL,
+                                    to = c(0, 100),
+                                    range = NULL,
                                     ignore_case = FALSE,
                                     ...) {
   # evaluate arguments
