@@ -344,7 +344,7 @@ degroup <- function(x,
 
   if (center == "mode") {
     x_gm_list <- lapply(select, function(i) {
-      stats::ave(dat[[i]], dat[[group]], FUN = function(.gm) .mode(stats::na.omit(.gm)))
+      stats::ave(dat[[i]], dat[[group]], FUN = function(.gm) distribution_mode(stats::na.omit(.gm)))
     })
   } else if (center == "median") {
     x_gm_list <- lapply(select, function(i) {
