@@ -22,6 +22,7 @@
 #'   (based on [stats::IQR()], using `type = 6`).
 #' @param verbose Toggle warnings and messages.
 #' @inheritParams bayestestR::point_estimate
+#' @inheritParams find_columns
 #'
 #' @details If `x` is a dataframe, only numeric variables are kept and will be displayed in the summary.
 #'
@@ -32,6 +33,8 @@
 #' `describe_distribution(list(mtcars$mpg))`), then `"mtcars$mpg"` is used as
 #' variable name.
 #'
+#' @inheritSection center Selection of variables - the `select` argument
+
 #' @note There is also a
 #'   [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
 #'   implemented in the
@@ -50,9 +53,17 @@ describe_distribution <- function(x, ...) {
   UseMethod("describe_distribution")
 }
 
-#' @rdname describe_distribution
-#' @export
 
+#' @export
+describe_distribution.default <- function(x, verbose = TRUE, ...) {
+  if (verbose) {
+    warning(insight::format_message(paste0("Can't describe variables of class '", class(x)[1], "'.")), call. = FALSE)
+  }
+  NULL
+}
+
+
+#' @export
 describe_distribution.list <- function(x,
                                        centrality = "mean",
                                        dispersion = TRUE,
@@ -130,9 +141,9 @@ describe_distribution.list <- function(x,
   out
 }
 
+
 #' @rdname describe_distribution
 #' @export
-
 describe_distribution.numeric <- function(x,
                                           centrality = "mean",
                                           dispersion = TRUE,
@@ -144,6 +155,7 @@ describe_distribution.numeric <- function(x,
                                           threshold = .1,
                                           verbose = TRUE,
                                           ...) {
+  insight::check_if_installed("bayestestR")
   out <- data.frame(.temp = 0)
 
   # Missing
@@ -289,7 +301,6 @@ describe_distribution.factor <- function(x,
 }
 
 
-#' @rdname describe_distribution
 #' @export
 describe_distribution.character <- function(x,
                                             dispersion = TRUE,
@@ -351,10 +362,11 @@ describe_distribution.character <- function(x,
 }
 
 
-
 #' @rdname describe_distribution
 #' @export
 describe_distribution.data.frame <- function(x,
+                                             select = NULL,
+                                             exclude = NULL,
                                              centrality = "mean",
                                              dispersion = TRUE,
                                              iqr = TRUE,
@@ -364,12 +376,13 @@ describe_distribution.data.frame <- function(x,
                                              ci = NULL,
                                              iterations = 100,
                                              threshold = .1,
+                                             ignore_case = FALSE,
                                              verbose = TRUE,
                                              ...) {
-
+  select <- .select_nse(select, x, exclude, ignore_case)
   # The function currently doesn't support descriptive summaries for character
   # or factor types.
-  out <- do.call(rbind, lapply(x, function(i) {
+  out <- do.call(rbind, lapply(x[select], function(i) {
     if ((include_factors && is.factor(i)) || (!is.character(i) && !is.factor(i))) {
       describe_distribution(
         i,
@@ -399,10 +412,10 @@ describe_distribution.data.frame <- function(x,
 }
 
 
-
-
 #' @export
 describe_distribution.grouped_df <- function(x,
+                                             select = NULL,
+                                             exclude = NULL,
                                              centrality = "mean",
                                              dispersion = TRUE,
                                              iqr = TRUE,
@@ -412,15 +425,17 @@ describe_distribution.grouped_df <- function(x,
                                              ci = NULL,
                                              iterations = 100,
                                              threshold = .1,
+                                             ignore_case = FALSE,
                                              verbose = TRUE,
                                              ...) {
   group_vars <- setdiff(colnames(attributes(x)$groups), ".rows")
   group_data <- expand.grid(lapply(x[group_vars], function(i) unique(sort(i))))
   groups <- split(x, x[group_vars])
+  select <- .select_nse(select, x, exclude, ignore_case)
 
   out <- do.call(rbind, lapply(1:length(groups), function(i) {
     d <- describe_distribution.data.frame(
-      groups[[i]],
+      groups[[i]][select],
       centrality = centrality,
       dispersion = dispersion,
       iqr = iqr,
@@ -446,6 +461,9 @@ describe_distribution.grouped_df <- function(x,
 
 
 
+
+# methods ------------------
+
 #' @export
 print.parameters_distribution <- function(x, digits = 2, ...) {
   formatted_table <- format(
@@ -475,3 +493,27 @@ print.parameters_distribution <- function(x, digits = 2, ...) {
   )
   out[[1]]
 }
+
+# distribution_mode ----------------------------------
+
+#' Compute mode for a statistical distribution
+#'
+#' @param x An atomic vector, a list, or a data frame.
+#'
+#' @return
+#'
+#' The value that appears most frequently in the provided data.
+#' The returned data structure will be the same as the entered one.
+#'
+#' @examples
+#'
+#' distribution_mode(c(1, 2, 3, 3, 4, 5))
+#' distribution_mode(c(1.5, 2.3, 3.7, 3.7, 4.0, 5))
+#'
+#' @export
+distribution_mode <- function(x) {
+  uniqv <- unique(x)
+  tab <- tabulate(match(x, uniqv))
+  idx <- which.max(tab)
+  uniqv[idx]
+}
