@@ -59,7 +59,9 @@
                               remove_na = "none",
                               reference = NULL,
                               .center = NULL,
-                              .scale = NULL) {
+                              .scale = NULL,
+                              keep_character = FALSE,
+                              preserve_value_labels = FALSE) {
 
   # check append argument, and set default
   if (isFALSE(append)) {
@@ -77,7 +79,7 @@
     }
   }
 
-  select <- .select_variables(x, select, exclude, force)
+  select <- .select_variables(x, select, exclude, force, keep_character)
 
   # check if selected variables are in reference
   if (!is.null(reference) && !all(select %in% names(reference))) {
@@ -85,7 +87,11 @@
   }
 
   # copy label attributes
-  variable_labels <- compact_list(lapply(x, function(i) attributes(i)$label))
+  variable_labels <- compact_list(lapply(x, function(i) attr(i, "label", exact = TRUE)))
+  value_labels <- NULL
+  if (preserve_value_labels) {
+    value_labels <- compact_list(lapply(x, function(i) attr(i, "labels", exact = TRUE)))
+  }
 
   # drop NAs
   remove_na <- match.arg(remove_na, c("none", "selected", "all"))
@@ -106,6 +112,9 @@
     if (length(variable_labels)) {
       variable_labels <- c(variable_labels, stats::setNames(variable_labels[select], colnames(new_variables)))
     }
+    if (length(value_labels)) {
+      value_labels <- c(value_labels, stats::setNames(value_labels[select], colnames(new_variables)))
+    }
     x <- cbind(x, new_variables)
     select <- colnames(new_variables)
   }
@@ -156,6 +165,12 @@
     }
   }
 
+  if (preserve_value_labels && length(value_labels)) {
+    for (i in names(value_labels)) {
+      attr(x[[i]], "labels") <- value_labels[[i]]
+    }
+  }
+
   list(
     x = x,
     select = select,
@@ -239,7 +254,7 @@
 
 ## variables to standardize and center ----
 
-.select_variables <- function(x, select, exclude, force) {
+.select_variables <- function(x, select, exclude, force, keep_character = FALSE) {
   if (is.null(select)) {
     select <- names(x)
   }
@@ -249,7 +264,11 @@
   }
 
   if (!force) {
-    factors <- sapply(x[select], function(i) is.factor(i) | is.character(i))
+    if (!keep_character) {
+      factors <- sapply(x[select], function(i) is.factor(i) | is.character(i))
+    } else {
+      factors <- sapply(x[select], function(i) is.factor(i))
+    }
     select <- select[!factors]
   }
 
@@ -277,6 +296,11 @@
     return(as.numeric(x))
   }
 
+  # Logicals should be 0/1
+  if (is.logical(x)) {
+    return(as.numeric(x))
+  }
+
   if (anyNA(suppressWarnings(as.numeric(as.character(stats::na.omit(x)))))) {
     if (is.character(x)) {
       x <- as.factor(x)
