@@ -4,6 +4,6 @@ test_that("testing Winsorization of factors", {
 })
 
 test_that("with missing values", {
-  expect_snapshot(winsorize(na.omit(ggplot2::msleep$brainwt)))
+  expect_snapshot(suppressWarnings(head(winsorize(na.omit(ggplot2::msleep$brainwt)))))
   expect_equal(length(winsorize(as.factor(ggplot2::msleep$vore))), 83)
 })
